Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Column ¶
type Column struct {
Status string
Issues []*issue.Issue
Cursor int
Offset int // scroll offset for windowing
}
Column represents a status column on the board.
type FilterFunc ¶
FilterFunc is a predicate for filtering issues in the board.
type KeyMap ¶
type KeyMap struct {
Left key.Binding
Right key.Binding
Up key.Binding
Down key.Binding
MoveLeft key.Binding
MoveRight key.Binding
Enter key.Binding
Escape key.Binding
Quit key.Binding
}
KeyMap defines the key bindings for the board.
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model is the main bubbletea model for the board.
func NewModel ¶
func NewModel(issues []*issue.Issue, issuesDir string, cfg *config.Config, filters ...FilterFunc) Model
NewModel creates a board model from the given issues.
Click to show internal directories.
Click to hide internal directories.